# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    AccessKeys,
    Action,
    ArmDisasterRecovery,
    ArmDisasterRecoveryProperties,
    CheckNameAvailability,
    CheckNameAvailabilityResult,
    ConfidentialCompute,
    ConnectionState,
    CorrelationFilter,
    Encryption,
    ErrorAdditionalInfo,
    ErrorResponse,
    ErrorResponseError,
    FailOver,
    FailOverProperties,
    FailoverPropertiesProperties,
    GeoDataReplicationProperties,
    Identity,
    KeyVaultProperties,
    MessageCountDetails,
    MigrationConfigProperties,
    MigrationConfigPropertiesProperties,
    NWRuleSetIpRules,
    NWRuleSetVirtualNetworkRules,
    NamespaceFailoverProperties,
    NamespaceReplicaLocation,
    NetworkRuleSet,
    NetworkRuleSetProperties,
    NetworkSecurityPerimeter,
    NetworkSecurityPerimeterConfiguration,
    NetworkSecurityPerimeterConfigurationProperties,
    NetworkSecurityPerimeterConfigurationPropertiesProfile,
    NetworkSecurityPerimeterConfigurationPropertiesResourceAssociation,
    NspAccessRule,
    NspAccessRuleProperties,
    NspAccessRulePropertiesSubscriptionsItem,
    Operation,
    OperationDisplay,
    PlatformCapabilities,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionProperties,
    PrivateLinkResource,
    PrivateLinkResourceProperties,
    PrivateLinkResourcesListResult,
    ProvisioningIssue,
    ProvisioningIssueProperties,
    ProxyResource,
    RegenerateAccessKeyParameters,
    Resource,
    ResourceNamespacePatch,
    Rule,
    Ruleproperties,
    SBAuthorizationRule,
    SBAuthorizationRuleProperties,
    SBClientAffineProperties,
    SBNamespace,
    SBNamespaceProperties,
    SBNamespaceUpdateParameters,
    SBNamespaceUpdateProperties,
    SBQueue,
    SBQueueProperties,
    SBSku,
    SBSubscription,
    SBSubscriptionProperties,
    SBTopic,
    SBTopicProperties,
    SqlFilter,
    Subnet,
    SystemData,
    TrackedResource,
    UserAssignedIdentity,
    UserAssignedIdentityProperties,
)

from ._enums import (  # type: ignore
    AccessRights,
    CreatedByType,
    DefaultAction,
    EndPointProvisioningState,
    EntityStatus,
    FilterType,
    GeoDRRoleType,
    IpAddressType,
    KeyType,
    ManagedServiceIdentityType,
    MigrationConfigurationName,
    Mode,
    NetworkRuleIPAction,
    NetworkSecurityPerimeterConfigurationProvisioningState,
    NspAccessRuleDirection,
    PrivateLinkConnectionStatus,
    ProvisioningStateDR,
    PublicNetworkAccess,
    PublicNetworkAccessFlag,
    ResourceAssociationAccessMode,
    RoleDisasterRecovery,
    SkuName,
    SkuTier,
    TlsVersion,
    UnavailableReason,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AccessKeys",
    "Action",
    "ArmDisasterRecovery",
    "ArmDisasterRecoveryProperties",
    "CheckNameAvailability",
    "CheckNameAvailabilityResult",
    "ConfidentialCompute",
    "ConnectionState",
    "CorrelationFilter",
    "Encryption",
    "ErrorAdditionalInfo",
    "ErrorResponse",
    "ErrorResponseError",
    "FailOver",
    "FailOverProperties",
    "FailoverPropertiesProperties",
    "GeoDataReplicationProperties",
    "Identity",
    "KeyVaultProperties",
    "MessageCountDetails",
    "MigrationConfigProperties",
    "MigrationConfigPropertiesProperties",
    "NWRuleSetIpRules",
    "NWRuleSetVirtualNetworkRules",
    "NamespaceFailoverProperties",
    "NamespaceReplicaLocation",
    "NetworkRuleSet",
    "NetworkRuleSetProperties",
    "NetworkSecurityPerimeter",
    "NetworkSecurityPerimeterConfiguration",
    "NetworkSecurityPerimeterConfigurationProperties",
    "NetworkSecurityPerimeterConfigurationPropertiesProfile",
    "NetworkSecurityPerimeterConfigurationPropertiesResourceAssociation",
    "NspAccessRule",
    "NspAccessRuleProperties",
    "NspAccessRulePropertiesSubscriptionsItem",
    "Operation",
    "OperationDisplay",
    "PlatformCapabilities",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionProperties",
    "PrivateLinkResource",
    "PrivateLinkResourceProperties",
    "PrivateLinkResourcesListResult",
    "ProvisioningIssue",
    "ProvisioningIssueProperties",
    "ProxyResource",
    "RegenerateAccessKeyParameters",
    "Resource",
    "ResourceNamespacePatch",
    "Rule",
    "Ruleproperties",
    "SBAuthorizationRule",
    "SBAuthorizationRuleProperties",
    "SBClientAffineProperties",
    "SBNamespace",
    "SBNamespaceProperties",
    "SBNamespaceUpdateParameters",
    "SBNamespaceUpdateProperties",
    "SBQueue",
    "SBQueueProperties",
    "SBSku",
    "SBSubscription",
    "SBSubscriptionProperties",
    "SBTopic",
    "SBTopicProperties",
    "SqlFilter",
    "Subnet",
    "SystemData",
    "TrackedResource",
    "UserAssignedIdentity",
    "UserAssignedIdentityProperties",
    "AccessRights",
    "CreatedByType",
    "DefaultAction",
    "EndPointProvisioningState",
    "EntityStatus",
    "FilterType",
    "GeoDRRoleType",
    "IpAddressType",
    "KeyType",
    "ManagedServiceIdentityType",
    "MigrationConfigurationName",
    "Mode",
    "NetworkRuleIPAction",
    "NetworkSecurityPerimeterConfigurationProvisioningState",
    "NspAccessRuleDirection",
    "PrivateLinkConnectionStatus",
    "ProvisioningStateDR",
    "PublicNetworkAccess",
    "PublicNetworkAccessFlag",
    "ResourceAssociationAccessMode",
    "RoleDisasterRecovery",
    "SkuName",
    "SkuTier",
    "TlsVersion",
    "UnavailableReason",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
